package com.goldenwater.slaj.ttsa.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.ttsa.domain.ObjTtsaExamAppl;

@Mapper
public interface ObjTtsaExamApplMapper {
    ObjTtsaExamAppl selectObjTtsaExamApplByGuid(String guid);
    List<ObjTtsaExamAppl> selectObjTtsaExamApplList(ObjTtsaExamAppl objTtsaExamAppl);
    int insertObjTtsaExamAppl(ObjTtsaExamAppl objTtsaExamAppl);
    int updateObjTtsaExamAppl(ObjTtsaExamAppl objTtsaExamAppl);
    int deleteObjTtsaExamApplByGuid(String guid);
    int deleteObjTtsaExamApplByGuids(String[] guids);
}
